import requests
import logging
import urllib3
import xml.etree.ElementTree as ET

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
default_logger = logging.getLogger(__name__)


class VMwareUAGAPI:
    def __init__(self, base_url, username, password, logger=default_logger):
        self.base_url = base_url
        self.auth = (username, password)
        self.logger = logger

    def make_request(self, url, method="GET", retries=5):
        url = f"{self.base_url}{url}"
        self.logger.info(f"Calling '{url}'")

        for i in range(retries):
            try:
                r = requests.request(method, url, verify=False, auth=self.auth)
                if r.status_code <= 400:
                    return ET.fromstring(r.text)
                else:
                    self.logger.warning(f"Calling {url} returned {r}: '{r.text}'")
            except Exception:
                self.logger.exception(f"Failed calling url {url}")

        self.logger.error(f"Failed to call {url} after {retries} retries, giving up")
        return None

    def monitor_stats(self):
        return self.make_request(f"/v1/monitor/stats")


def main():
    default_logger.setLevel(logging.DEBUG)
    st = logging.StreamHandler()
    st.setLevel(logging.DEBUG)
    default_logger.addHandler(st)

    import json
    import pprint

    with open("properties.json", "r") as f:
        config = json.load(f)

    base_url = config.get("base_url")
    username = config.get("username")
    password = config.get("password")

    v = VMwareUAGAPI(base_url, username, password)

    tree: ET.Element = v.monitor_stats()
    print("sessionCount", tree.findtext("sessionCount"))
    print("authenticatedSessionCount", tree.findtext("authenticatedSessionCount"))
    print("authenticatedViewSessionCount", tree.findtext("authenticatedViewSessionCount"))
    print("openIncomingConnectionCount", tree.findtext("openIncomingConnectionCount"))
    print("overallStatus", tree.find("overAllStatus").findtext("status"))
    print("failedLoginAttempts", tree.find("edgeServiceSessionStats").findtext("failedLoginAttempts"))
    print("authenticatedSessions", tree.find("edgeServiceSessionStats").findtext("authenticatedSessions"))
    print("unauthenticatedSessions", tree.find("edgeServiceSessionStats").findtext("unauthenticatedSessions"))
    print("failedLoginAttempts", tree.find("edgeServiceSessionStats").findtext("failedLoginAttempts"))
    print("userCount", tree.find("edgeServiceSessionStats").findtext("userCount"))

    # for child in tree:  # type: ET.Element
    #     print(child.tag, child.text)


if __name__ == "__main__":
    main()
