import logging
import xml.etree.ElementTree as ET

from ruxit.api.base_plugin import RemoteBasePlugin

from vmware_uag_api import VMwareUAGAPI
from plugin_utils import time_it, exception_logger

logger = logging.getLogger(__name__)


class VMwareUAGPlugin(RemoteBasePlugin):

    def initialize(self, **kwargs):
        self.executions = 0

    @time_it
    @exception_logger
    def query(self, **kwargs) -> None:

        config = kwargs["config"]

        group = self.topology_builder.create_group(config.get("group"), config.get("group"))
        device = group.create_device(config.get("alias"))

        frequency = int(config.get("frequency", 1))

        if self.executions % frequency == 0:
            client = VMwareUAGAPI(config.get("base_url"), config.get("username"), config.get("password"), logger=logger)

            tree: ET.Element = client.monitor_stats()

            device.absolute("sessionCount", tree.findtext("sessionCount"))
            device.absolute("authenticatedSessionCount", tree.findtext("authenticatedSessionCount"))
            device.absolute("openIncomingConnectionCount", tree.findtext("openIncomingConnectionCount"))
            device.absolute("authenticatedSessions", tree.find("edgeServiceSessionStats").findtext("authenticatedSessions"))
            device.absolute("unauthenticatedSessions", tree.find("edgeServiceSessionStats").findtext("unauthenticatedSessions"))
            device.absolute("failedLoginAttempts", tree.find("edgeServiceSessionStats").findtext("failedLoginAttempts"))
            device.absolute("userCount", tree.find("edgeServiceSessionStats").findtext("userCount"))
        else:
            logger.info(f"Not running because {self.executions} is not divisible by {frequency}")
        self.executions += 1
